// ----------------------------------------
// Includes
// ----------------------------------------
#include "StrapDisplayInputManager.h"
#include <Arduino.h>

void StrapDisplayInputManager::readSoftPots(){

  // Fill input puffer with analog sensor values
  inputBuffer[inputBufferIndex][softPotLeftID] = analogRead(SOFTPOT_LEFT_PIN);
  inputBuffer[inputBufferIndex][softPotMiddleID] = analogRead(SOFTPOT_MIDDLE_PIN);
  inputBuffer[inputBufferIndex][softPotRightID] = analogRead(SOFTPOT_RIGHT_PIN);

  // Print Sensor Values for Debug
  if (bDebugSoftPots) {
    printSoftPotsVals(inputBufferIndex);
  }

  if (inputBufferIndex == (SOFTPOT_PUFFER_SIZE - 1)) {
    inputBufferIndex = 0;
  }
  else {
    inputBufferIndex++;
  }
}

bool StrapDisplayInputManager::checkInputRegion(InputRegion region, int triggerThreshold) {

  // Check whether the trigger threshold exceeds the puffer size
  if (triggerThreshold > SOFTPOT_PUFFER_SIZE) {
    triggerThreshold = SOFTPOT_PUFFER_SIZE;
  }

  // Go through the input buffer values
  for (int i = 0; i < triggerThreshold; i++) {
    // if the input buffer have a value that is not in the range (minYVal-maxYV@xVal) then return false;
    if (!(inputBuffer[i][region.xVal] >= region.minYVal && inputBuffer[i][region.xVal] <= region.maxYVal))
      return false;
  }
  // else return true (all buffer values are in the range)
  return true;
}

void StrapDisplayInputManager::debugSoftPots(bool debugSoftPotsVals){
  bDebugSoftPots= debugSoftPotsVals;
}

void StrapDisplayInputManager::printSoftPotsVals(int pufferPos) {
  Serial.print(inputBuffer[pufferPos][softPotLeftID]);
  Serial.print("/");
  Serial.print(inputBuffer[pufferPos][softPotMiddleID]);
  Serial.print("/");
  Serial.println(inputBuffer[pufferPos][softPotRightID]);
}
