// ----------------------------------------
// Includes
// ----------------------------------------
#include "strapDisplayApp.h"

void StrapDisplayApp::registerEPD(PL_smallLegio *epd){
  epdRef = epd;
}

int StrapDisplayApp::runApplication(){
  return 0;
}

void StrapDisplayApp::show(){
}

void StrapDisplayApp::registerStrapDisplayCore(StrapDisplayInputManager *strapDisplayCore){
  strapDisplayCoreRef = strapDisplayCore;
}

bool StrapDisplayApp::checkInputRegion(InputRegion region, int triggerThreshold) {

  // Check whether the trigger threshold exceeds the puffer size
  if (triggerThreshold > SOFTPOT_PUFFER_SIZE) {
    triggerThreshold = SOFTPOT_PUFFER_SIZE;
  }

  // Go through the input buffer values
  for (int i = 0; i < triggerThreshold; i++) {
    // if the input buffer have a value that is not in the range (minYVal-maxYV@xVal) then return false;
    if (!(inputBuffer[i][region.xVal] >= region.minYVal && inputBuffer[i][region.xVal] <= region.maxYVal))
      return false;
  }
  // else return true (all buffer values are in the range)
  return true;
}

void StrapDisplayApp::readSoftPots(){

  // Fill input puffer with analog sensor values
  inputBuffer[inputBufferIndex][softPotLeftID] = analogRead(SOFTPOT_LEFT_PIN);
  inputBuffer[inputBufferIndex][softPotMiddleID] = analogRead(SOFTPOT_MIDDLE_PIN);
  inputBuffer[inputBufferIndex][softPotRightID] = analogRead(SOFTPOT_RIGHT_PIN);

  // Print Sensor Values for Debug
  if (bDebugSoftPots) {
    printSoftPotsVals(inputBufferIndex);
  }

  if (inputBufferIndex == (SOFTPOT_PUFFER_SIZE - 1)) {
    inputBufferIndex = 0;
  }
  else {
    inputBufferIndex++;
  }
}

void StrapDisplayApp::debugSoftPots(bool debugSoftPotsVals){
  bDebugSoftPots= debugSoftPotsVals;
}

void StrapDisplayApp::printSoftPotsVals(int pufferPos) {
  Serial.print(inputBuffer[pufferPos][softPotLeftID]);
  Serial.print("/");
  Serial.print(inputBuffer[pufferPos][softPotMiddleID]);
  Serial.print("/");
  Serial.println(inputBuffer[pufferPos][softPotRightID]);
}


void StrapDisplayApp::drawAppIcon(int xPos, int yPos, int color){

  if(color == iconBlackPixel){
      epdRef->drawBitmap(xPos,yPos,StrapDisplayApp_ICON_BLACK,50,50,EPD_BLACK);
      epdRef->drawBitmap(xPos,yPos,StrapDisplayApp_ICON_YELLOW,50,50,EPD_BLACK);
      epdRef->drawBitmap(xPos,yPos,StrapDisplayApp_ICON_RED,50,50,EPD_BLACK);
      epdRef->drawBitmap(xPos,yPos,StrapDisplayApp_ICON_GREEN,50,50,EPD_BLACK);
      epdRef->drawRect(xPos-1,yPos-1,50+2,50+2,EPD_BLACK);
      epdRef->drawRect(xPos-2,yPos-2,50+4,50+4,EPD_BLACK);  
  }
  else if(color == iconRedPixel){
    epdRef->drawBitmap(xPos,yPos,StrapDisplayApp_ICON_RED,50,50,EPD_BLACK);
  }
  else if(color == iconYellowPixel){
    epdRef->drawBitmap(xPos,yPos,StrapDisplayApp_ICON_YELLOW,50,50,EPD_BLACK);
    epdRef->drawBitmap(xPos,yPos,StrapDisplayApp_ICON_GREEN,50,50,EPD_BLACK);
  }
  else if(color == iconGreenPixel){
    epdRef->drawBitmap(xPos,yPos,StrapDisplayApp_ICON_GREEN,50,50,EPD_BLACK);
  }
  else if(color == iconBluePixel){
    epdRef->drawBitmap(xPos,yPos,StrapDisplayApp_ICON_BLUE,50,50,EPD_BLACK);
  }  
}

void StrapDisplayApp::setApplicationID(int appID){
  applicationID = appID;
}

int StrapDisplayApp::getApplicationID(){
  return applicationID;
}

// changeStateTo()
// ----------------
void StrapDisplayApp::changeStateTo(const unsigned char screen[], int newState, boolean clearScreen) {

  // Clear previous image
  if (clearScreen) {
    epdRef->clearScreen(EPD_BLACK);
  }
  
  delay(1000);
  
  // Load new image
  epdRef->showImage(screen);
}
