// Includes
#include "strapDisplayAppPedometer.h"
#include "StrapDisplayInputManager.h"
#include "screens/app_pedometer.h"
#include "fonts/verticalNumbers.h"

void StrapDisplayAppPedometer::drawAppIcon(int xPos, int yPos, int color) {
  if (color == iconBlackPixel) {
    epdRef->drawBitmap(xPos, yPos, StrapDisplayAppPedometer_ICON_YELLOW, 50, 50, EPD_BLACK);
    epdRef->drawBitmap(xPos, yPos, StrapDisplayAppPedometer_ICON_GREEN, 50, 50, EPD_BLACK);
    epdRef->drawRect(xPos - 1, yPos - 1, 50 + 2, 50 + 2, EPD_BLACK);
    epdRef->drawRect(xPos - 2, yPos - 2, 50 + 4, 50 + 4, EPD_BLACK);
  }
  else if (color == iconYellowPixel) {
    epdRef->drawBitmap(xPos, yPos, StrapDisplayAppPedometer_ICON_YELLOW, 50, 50, EPD_BLACK);
    epdRef->drawBitmap(xPos, yPos, StrapDisplayAppPedometer_ICON_GREEN, 50, 50, EPD_BLACK);
  }
  else if (color == iconGreenPixel) {
    epdRef->drawBitmap(xPos, yPos, StrapDisplayAppPedometer_ICON_YELLOW, 50, 50, EPD_BLACK);
  }
}

void StrapDisplayAppPedometer::updateScreen() {

  epdRef->setFont(&VerticalNumbers);
  epdRef->setTextSize(2.5);
  
  int activityStepCounter = lsm6ds33Ref->readPedometer();
  String strNumber = String(activityStepCounter);

  epdRef->clearScreen(EPD_BLACK);
  delay(1000);
  epdRef->showImage(SCREEN_PEDOMETER);
  delay(1000);

  // Display current step count...
  // >> The layout depens on the length of activityStepCounter...
  if (strNumber.length() < 4) {
    printNumber(activityStepCounter, 45, 62);
  }
  else if (strNumber.length() == 4) {
    printNumber(activityStepCounter, 45, 75);
  }
  else if (strNumber.length() == 5) {
    printNumber(activityStepCounter, 45, 88);
  }
  else if (strNumber.length() == 6) {
    printNumber(activityStepCounter, 45, 101);
  }

  // Display day goal indicator...
  if (activityStepCounter > 10000)activityStepCounter = 10000;          // cut maxima
  float fStepGoalPercentage = (float)(activityStepCounter / 10000.0f);  // compute percentage
  fStepGoalPercentage = (float)(fStepGoalPercentage * 100.0f);          // convert to int
  int iStepGoalPercentage = (int)(fStepGoalPercentage + 0.5f);

  int calculatedYPos = map(iStepGoalPercentage, 0, 100, 135, 20);       // copmuter y position of indicator symbol
  epdRef->setCursor(105, calculatedYPos);                               // set cursor
  epdRef->print("/");                                                   // display indicator symbol

  epdRef->updateLegio(EPD_BLUE);
}

void StrapDisplayAppPedometer::show() {
  updateScreen();
}

void StrapDisplayAppPedometer::init() {
  updateStepsButton.minYVal = 420;
  updateStepsButton.maxYVal = 520;
  updateStepsButton.xVal = softPotLeftID;
  pedometerBackButton.minYVal = 650;
  pedometerBackButton.maxYVal = 750;
  pedometerBackButton.xVal = softPotLeftID;
  epdRef->setFont(&VerticalNumbers);
  epdRef->setTextSize(2.5);
}

int StrapDisplayAppPedometer::runApplication() {

  // Read SoftPot Values...
  strapDisplayCoreRef->readSoftPots();

  if (strapDisplayCoreRef->checkInputRegion(updateStepsButton)) {
    updateScreen();
    return APP_IS_RUNNING;
  }
  else if (strapDisplayCoreRef->checkInputRegion(pedometerBackButton)) {
    return APP_EXIT;
  }

  return APP_IS_RUNNING;
}

void StrapDisplayAppPedometer::printNumber(int number, int xPos, int yPos, int characterOffset) {
  epdRef->clear();
  epdRef->setCursor(xPos, yPos);
  String strNumber = String(number);
  for (int i = 0; i < strNumber.length(); i++) {
    epdRef->print(strNumber[i]);
    epdRef->setCursor(xPos, epdRef->getCursorY() + characterOffset);
  }
}

void StrapDisplayAppPedometer::registerLSM6DS33(Adafruit_LSM6DS33 *lsm6ds33) {
  lsm6ds33Ref = lsm6ds33;
}
